@@ -6,7 +6,7 @@ use EV;
 use Net::Curl::Easy qw(CURLE_COULDNT_CONNECT);
 use Net::Curl::Multi qw(CURLMSG_DONE CURL_SOCKET_TIMEOUT /^CURL_POLL_/ /^CURL_CSELECT_/ CURLMOPT_SOCKETFUNCTION CURLMOPT_TIMERFUNCTION);
 
-our $VERSION = '0.01.4';
+our $VERSION = '0.01.5';
 
 BEGIN {
 	Net::Curl::Multi->can('CURLMOPT_TIMERFUNCTION') or
@@ -44,6 +44,8 @@ sub curl_ev {
 
 	my $cb_timeout = sub { $socket_action->(CURL_SOCKET_TIMEOUT) };
 
+	my $add_handle_timer;
+
 	# add one handle and kickstart download
 	my $add_handle = sub {
 		my ($easy, $finish, $timeout) = @_;
@@ -62,7 +64,7 @@ sub curl_ev {
 		# and it could confuse our application -- it would appear to
 		# have finished before it started.
 
-		EV::timer 0, 0, $cb_timeout;
+		$add_handle_timer = EV::timer 0, 0, $cb_timeout;
 
 		$multi->add_handle($easy);
 
@@ -129,7 +131,8 @@ sub curl_ev {
 			$timer = EV::timer 10, 10, $cb_timeout;
 		} else {
 			# This will trigger timeouts if there are any.
-			$timer = EV::timer $timeout_ms / 1000, 0, $cb_timeout;
+			my $t = $timeout_ms / 1000;
+			$timer = EV::timer $t, $t, $cb_timeout;
 		}
 
 		return 1;
@@ -201,5 +204,6 @@ at your option, any later version of Perl 5 you may have available.
 
 L<EV>
 L<Net::Curl>
+L<http://search.cpan.org/~syp/Net-Curl/lib/Net/Curl/examples.pod#Multi::Event>
 
 =cut
